switch(i){case 1:1;case 2:2}
function x(){switch(typeof v){case"boolean":return new global.Boolean(v);case"number":i=1;break;return new global.Number(v);case"string":return new global.String(v);case"function":return v;case"object":if(v!==null)return v}};switch(t){case BITWISE_OR:v=u|v;break;case BITWISE_XOR:v=u^v;break;case BITWISE_AND:v=u&v;break;case LSH:v=u<<v;break;case RSH:v=u>>v;break;case URSH:v=u>>>v;break;case PLUS:v=u+v;break;case MINUS:v=u-v;break;case MUL:v=u*v;break;case DIV:v=u/v;break;case MOD:v=u%v;break}
