i=0;
bob: i=0;
i=0;

bob:
if(x){}

{do { 
			t;
                } while(t);
t;}

if (t){ 
                do { 
			t;
                } while(t);
                t;
}

switch(i) {
  case "x":
    

 case LEFT_CURLY:
          //object_init:
            if (t){ 
                do { 
			t;
                } while(t);
                t;
            }

}