w=x*y+1/2
{z=z + 1}

1
+ 2

"Prototype does not have an ancestor: "
	+ currentConstructor + "."

Error("Prototype does not have an ancestor: " + currentConstructor + ".")

// Expression inside func call with a newline inside them
Error("Prototype does not have an ancestor: "
	+ currentConstructor + ".")
